# iBoot —— AI模型服务化引擎

将Python程序封装成为Web互联网服务。尤其适用于AI模型推理程序的互联网化部署。

目前提供RESTful API、WebSocket和可视化Web GUI等多种形式的互联网API接口服务，支持二进制数据传输和文件上传。

## 依赖包地址 

- https://pypi.org/project/iboot

## 依赖包引用

    $ pip install iboot

## 应用开发实例

- CubeAI智立方

    - https://git.openi.org.cn/OpenI/cubeai
    - https://git.openi.org.cn/OpenI/cubeai_examples
